@@ -1,7 +1,9 @@
-
 #' maxWithoutNA
+#'
 #' Function that returns NA if all elements are NA, and the max value not NA, if not.
+#'
 #' @param x vector parameter
+#' @noRd
 maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm = TRUE), NA)
 
 
@@ -34,7 +36,7 @@ maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm = TRUE), NA)
 #' @importFrom utils read.csv
 #' @importFrom digest digest
 #' @importFrom R6 R6Class
-#' @export
+#' @noRd
 ScraperLedger.class <- R6::R6Class("ScraperLedger",
  public = list(
    states = NULL,
@@ -51,6 +53,7 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
                            end.scrape   = as.POSIXct(character()),
                            status       = character(),
                            scraped.name = character(),
+                           symbol       = character(),
                            scraped.vertices   = numeric(),
                            scraped.faces      = numeric(),
                            status.test        = character(),
@@ -74,7 +77,7 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
      r <- NULL
      default.status <- "queued"
      if (is.null(self$getIdFilename(source, source.filename))){
-       futile.logger::flog.info(paste("Adding Filename to ledger ",
+       futile.logger::flog.debug(paste("Adding Filename to ledger ",
                                       source,
                                       source.filename))
        r <- nrow(self$df) + 1
@@ -177,6 +180,7 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
          #in a different commands for not converting it to character
          if (status %in% "scraped"){
            scraped.name <- scraped.polyhedron$getName()
+           symbol       <- scraped.polyhedron$getState()$getSymbol()
            scraped.vertices <- nrow(scraped.polyhedron$getState()$
                                       getVertices(solid = TRUE))
            scraped.faces    <- length(scraped.polyhedron$getState()$getSolid())
@@ -207,10 +211,18 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
            if (nchar(error) > 0){
              stop(error)
            }
-           fields.update <- c(fields.update, "scraped.name", "crc.filename")
-           values.update <- c(values.update, scraped.name.lower, crc.filename)
+
+           fields.update <- c(fields.update,
+                              "scraped.name",
+                              "symbol",
+                              "crc.filename")
+           values.update <- c(values.update,
+                              scraped.name.lower,
+                              symbol,
+                              crc.filename)
            fields.numeric.update <- c(fields.numeric.update,
-                                     "scraped.vertices", "scraped.faces")
+                                     "scraped.vertices",
+                                     "scraped.faces")
            values.numeric.update <- c(values.numeric.update,
                                       scraped.vertices,
                                       scraped.faces)
@@ -260,13 +272,19 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
                                  resolveScrapedPreloaded(x = x,
                                                          field = "faces")
                                  }))
+       self$df$faces    <-  as.numeric(apply(self$df, MARGIN = 1,
+                                 FUN = function(x) {
+                                   resolveScrapedPreloaded(x = x,
+                                                   field = "faces")
+                                 }))
+
        self$dirty <- FALSE
      }
    },
    getAvailablePolyhedra = function(sources = names(
            getPackageEnvir(".available.sources")),
            search.string = "",
-           ret.fields = c("source", "scraped.name", "vertices",
+           ret.fields = c("source", "scraped.name", "symbol", "vertices",
                           "faces", "status"),
            ignore.case = TRUE){
 
